@@ -18,23 +18,14 @@ from ..utils.data_manager import RealDataManager, TradeInfo, TradingSummary
 try:
     from src.backtesting.report_generator import ReportGenerator
     from src.backtesting.performance_analyzer import PerformanceAnalyzer
-except ImportError:
+    BACKTESTING_AVAILABLE = True
+    BACKTESTING_IMPORT_ERROR = None
+except ImportError as e:
     # Fallback for testing or when backtesting modules are not available
-    class ReportGenerator:
-        def __init__(self, *args, **kwargs):
-            pass
-        
-        def generate_report(self, *args, **kwargs):
-            return {"status": "Report generation not available"}
-    
-    class PerformanceAnalyzer:
-        def __init__(self, *args, **kwargs):
-            pass
-        
-        def analyze(self, *args, **kwargs):
-            return {"status": "Performance analysis not available"}
     ReportGenerator = None
     PerformanceAnalyzer = None
+    BACKTESTING_AVAILABLE = False
+    BACKTESTING_IMPORT_ERROR = str(e)
 
 
 class AnalyticsCommand(BaseCommand):
@@ -42,6 +33,11 @@ class AnalyticsCommand(BaseCommand):
     
     def execute(self, args: Namespace) -> CommandResult:
         """Execute analytics command"""
+        # Check dependencies first
+        dependency_result = self._check_analytics_dependencies()
+        if not dependency_result.success:
+            return dependency_result
+        
         analysis_type = args.type
         days = getattr(args, 'days', 30)
         output_file = getattr(args, 'output', None)
@@ -88,6 +84,44 @@ class AnalyticsCommand(BaseCommand):
                 ]
             )
     
+    def _check_analytics_dependencies(self) -> CommandResult:
+        """Check analytics component dependencies"""
+        missing_components = []
+        suggestions = []
+        
+        # Check backtesting components
+        if not BACKTESTING_AVAILABLE:
+            missing_components.append("Backtesting modules")
+            suggestions.extend([
+                "Install backtesting dependencies: pip install genebot[backtesting]",
+                "Ensure src/backtesting modules are available",
+                f"Import error: {BACKTESTING_IMPORT_ERROR}"
+            ])
+        
+        # Check database dependencies (required for analytics)
+        db_result = self.check_database_dependencies(required=True)
+        if not db_result.success:
+            return db_result
+        
+        # Check ML dependencies (optional for advanced analytics)
+        ml_result = self.check_ml_dependencies(required=False)
+        if ml_result.status.value == 'warning':
+            suggestions.extend(ml_result.suggestions)
+        
+        if missing_components:
+            return CommandResult.error(
+                f"Missing analytics components: {', '.join(missing_components)}",
+                suggestions=suggestions
+            )
+        
+        if suggestions:
+            return CommandResult.warning(
+                "Analytics dependencies available with limitations",
+                suggestions=suggestions
+            )
+        
+        return CommandResult.success("Analytics dependencies available")
+    
     def _run_performance_analysis(self, data_manager: RealDataManager, days: int, 
                                 output_format: str, output_file: str) -> CommandResult:
         """Run comprehensive performance analysis"""
