@@ -8,6 +8,7 @@ Commands for controlling the trading bot lifecycle.
 from argparse import Namespace
 from typing import Dict, Any, Optional
 from datetime import timedelta
+from pathlib import Path
 import json
 
 from ..result import CommandResult
@@ -33,9 +34,6 @@ class StartBotCommand(BaseCommand):
         self.logger.section("Starting GeneBot Trading Engine")
         
         try:
-            # Initialize process manager
-            process_manager = ProcessManager(self.context.workspace_path)
-            
             if config_file:
                 self.logger.info(f"Using configuration file: {config_file}")
             
@@ -45,10 +43,13 @@ class StartBotCommand(BaseCommand):
             if accounts:
                 self.logger.info(f"Using accounts: {', '.join(accounts)}")
             
-            # Validate system configuration
+            # Validate system configuration (this may update workspace_path via auto-detection)
             self.logger.progress("Validating system configuration...")
             self._validate_system_config()
             
+            # Initialize process manager AFTER validation (so it uses the correct workspace_path)
+            process_manager = ProcessManager(self.context.workspace_path)
+            
             # Start bot process
             self.logger.progress("Starting bot processes...")
             
@@ -101,19 +102,87 @@ class StartBotCommand(BaseCommand):
                 ]
             )
     
+    def _auto_detect_workspace(self) -> bool:
+        """
+        Auto-detect workspace by looking for config directories in parent directories.
+        Updates context.workspace_path if found.
+        
+        Returns:
+            bool: True if workspace was found and updated, False otherwise
+        """
+        current_path = Path.cwd()
+        max_depth = 5  # Limit search to avoid infinite loops
+        
+        for i in range(max_depth):
+            config_dir = current_path / "config"
+            if config_dir.exists() and config_dir.is_dir():
+                # Found config directory, check if it has GeneBot configuration files
+                config_files = [
+                    "trading_bot_config.yaml",
+                    "multi_market_config.yaml", 
+                    "bot_config.yaml",
+                    "accounts.yaml"
+                ]
+                
+                has_config = any((config_dir / f).exists() for f in config_files)
+                if has_config:
+                    # Update the context to use this as workspace
+                    self.context.workspace_path = current_path
+                    self.context.config_path = config_dir
+                    self.logger.info(f"Auto-detected workspace: {current_path}")
+                    return True
+            
+            # Move to parent directory
+            parent = current_path.parent
+            if parent == current_path:  # Reached filesystem root
+                break
+            current_path = parent
+        
+        return False
+    
     def _validate_system_config(self) -> None:
         """Validate system configuration before starting"""
-        # Check if main.py exists
-        main_py = self.context.workspace_path / "main.py"
-        if not main_py.exists():
-            raise ProcessError(
-                "main.py not found in workspace",
-                suggestions=[
-                    "Ensure you're in the correct directory",
-                    "Check that main.py exists",
-                    "Verify workspace structure"
-                ]
-            )
+        # Note: We no longer require main.py in the workspace since we use the packaged runner
+        # Check if we have a valid workspace with configuration
+        config_dir = self.context.workspace_path / "config"
+        
+        # Try to auto-detect workspace if config directory doesn't exist
+        if not config_dir.exists():
+            workspace_found = self._auto_detect_workspace()
+            if not workspace_found:
+                # Provide more specific guidance based on the situation
+                current_dir = Path.cwd()
+                config_dir = current_dir / "config"
+                
+                # Check if this looks like a real workspace or just auto-created config
+                has_real_config = False
+                if config_dir.exists():
+                    # Check if config directory has actual configuration files
+                    config_files = [
+                        config_dir / "trading_bot_config.yaml",
+                        config_dir / "accounts.yaml"
+                    ]
+                    has_real_config = any(f.exists() for f in config_files)
+                
+                if has_real_config:
+                    # Config directory exists with real files - this should work
+                    self.context.workspace_path = current_dir
+                    self.context.config_path = config_dir
+                    self.logger.info(f"Using current directory as workspace: {current_dir}")
+                    return  # Configuration is valid, proceed
+                else:
+                    # No real config files - likely running from wrong location
+                    suggestions = [
+                        "Navigate to your GeneBot project directory",
+                        "If you don't have a project yet, run 'genebot init-config' to create one",
+                        "Use --config-path to specify the correct config directory path",
+                        "Ensure you're in a directory with a config/ folder containing configuration files"
+                    ]
+                
+                raise ProcessError(
+                    "No valid GeneBot workspace found",
+                    suggestions=suggestions
+                )
         
         # Check if config directory exists
         config_dir = self.context.workspace_path / "config"
