@@ -47,6 +47,16 @@ from .error_report import (
 )
 from .security import SecurityCommand
 from .completion import CompletionCommand
+from .orchestrator import (
+    StartOrchestratorCommand, StopOrchestratorCommand, OrchestratorStatusCommand,
+    OrchestratorConfigCommand, OrchestratorMonitorCommand, OrchestratorInterventionCommand,
+    OrchestratorAPICommand
+)
+from .orchestrator_migration import OrchestratorMigrationCommand
+from .performance import (
+    ProfileStartupCommand, MonitorPerformanceCommand, OptimizeSystemCommand,
+    ValidatePerformanceCommand, BenchmarkOperationCommand, PerformanceStatusCommand
+)
 
 
 class CommandRouter:
@@ -124,6 +134,37 @@ class CommandRouter:
             
             # Completion command
             'completion': CompletionCommand,
+            
+            # Orchestrator commands
+            'orchestrator-start': StartOrchestratorCommand,
+            'orchestrator-stop': StopOrchestratorCommand,
+            'orchestrator-status': OrchestratorStatusCommand,
+            'orchestrator-config': OrchestratorConfigCommand,
+            'orchestrator-monitor': OrchestratorMonitorCommand,
+            'orchestrator-intervention': OrchestratorInterventionCommand,
+            'orchestrator-api': OrchestratorAPICommand,
+            
+            # Orchestrator aliases
+            'orch-start': StartOrchestratorCommand,
+            'orch-stop': StopOrchestratorCommand,
+            'orch-status': OrchestratorStatusCommand,
+            'orch-config': OrchestratorConfigCommand,
+            'orch-monitor': OrchestratorMonitorCommand,
+            'orch-intervention': OrchestratorInterventionCommand,
+            'orch-api': OrchestratorAPICommand,
+            
+            # Migration commands
+            'orchestrator-migrate': OrchestratorMigrationCommand,
+            'orch-migrate': OrchestratorMigrationCommand,
+            
+            # Performance commands
+            'profile-startup': ProfileStartupCommand,
+            'monitor-performance': MonitorPerformanceCommand,
+            'optimize-system': OptimizeSystemCommand,
+            'validate-performance': ValidatePerformanceCommand,
+            'benchmark': BenchmarkOperationCommand,
+            'performance-status': PerformanceStatusCommand,
+            'perf-status': PerformanceStatusCommand,  # Alias
         }
     
     def route_command(self, command_name: str, args: Namespace) -> CommandResult:
