@@ -134,7 +134,7 @@ For more information, visit: https://github.com/genebot/genebot
     parser.add_argument(
         '--version', '-V',
         action='version',
-        version='GeneBot 1.1.23 - Advanced Multi-Market Trading Bot'
+        version='GeneBot 1.1.34 - Advanced Multi-Market Trading Bot'
     )
     
     # Add common arguments
@@ -165,9 +165,216 @@ For more information, visit: https://github.com/genebot/genebot
     # Error handling and recovery commands
     _add_error_handling_commands(subparsers)
     
+    # Orchestrator commands
+    _add_orchestrator_commands(subparsers)
+    
     return parser
 
 
+def _add_orchestrator_commands(subparsers) -> None:
+    """Add orchestrator management commands"""
+    
+    # Start orchestrator command
+    start_orch_parser = subparsers.add_parser(
+        'orchestrator-start',
+        aliases=['orch-start'],
+        help='Start the strategy orchestrator',
+        description='Start the unified strategy orchestration system'
+    )
+    start_orch_parser.add_argument(
+        '--config',
+        help='Orchestrator configuration file path'
+    )
+    start_orch_parser.add_argument(
+        '--daemon',
+        action='store_true',
+        help='Run orchestrator in daemon mode'
+    )
+    start_orch_parser.add_argument(
+        '--strategies',
+        nargs='+',
+        help='Specific strategies to enable (default: all configured)'
+    )
+    
+    # Stop orchestrator command
+    stop_orch_parser = subparsers.add_parser(
+        'orchestrator-stop',
+        aliases=['orch-stop'],
+        help='Stop the strategy orchestrator',
+        description='Gracefully stop the running orchestrator'
+    )
+    stop_orch_parser.add_argument(
+        '--timeout',
+        type=int,
+        default=60,
+        help='Shutdown timeout in seconds (default: 60)'
+    )
+    
+    # Orchestrator status command
+    status_orch_parser = subparsers.add_parser(
+        'orchestrator-status',
+        aliases=['orch-status'],
+        help='Show orchestrator status',
+        description='Display current orchestrator status and metrics'
+    )
+    status_orch_parser.add_argument(
+        '--verbose',
+        action='store_true',
+        help='Show detailed status information'
+    )
+    status_orch_parser.add_argument(
+        '--json',
+        action='store_true',
+        help='Output status in JSON format'
+    )
+    
+    # Orchestrator configuration command
+    config_orch_parser = subparsers.add_parser(
+        'orchestrator-config',
+        aliases=['orch-config'],
+        help='Manage orchestrator configuration',
+        description='View and manage orchestrator configuration'
+    )
+    config_orch_parser.add_argument(
+        'action',
+        choices=['show', 'update', 'validate', 'reload'],
+        help='Configuration action to perform'
+    )
+    config_orch_parser.add_argument(
+        '--config',
+        help='Configuration file path'
+    )
+    config_orch_parser.add_argument(
+        '--allocation-method',
+        choices=['equal_weight', 'performance_based', 'risk_parity', 'custom'],
+        help='Update allocation method'
+    )
+    config_orch_parser.add_argument(
+        '--rebalance-frequency',
+        choices=['daily', 'weekly', 'monthly'],
+        help='Update rebalance frequency'
+    )
+    config_orch_parser.add_argument(
+        '--max-drawdown',
+        type=float,
+        help='Update maximum portfolio drawdown limit'
+    )
+    
+    # Orchestrator monitoring command
+    monitor_orch_parser = subparsers.add_parser(
+        'orchestrator-monitor',
+        aliases=['orch-monitor'],
+        help='Monitor orchestrator performance',
+        description='Display real-time orchestrator monitoring information'
+    )
+    monitor_orch_parser.add_argument(
+        '--hours',
+        type=int,
+        default=24,
+        help='Time range in hours for monitoring data (default: 24)'
+    )
+    monitor_orch_parser.add_argument(
+        '--format',
+        choices=['table', 'json'],
+        default='table',
+        help='Output format (default: table)'
+    )
+    monitor_orch_parser.add_argument(
+        '--refresh',
+        type=int,
+        help='Auto-refresh interval in seconds'
+    )
+    
+    # Manual intervention command
+    intervention_parser = subparsers.add_parser(
+        'orchestrator-intervention',
+        aliases=['orch-intervention'],
+        help='Manual orchestrator interventions',
+        description='Perform manual interventions on the orchestrator'
+    )
+    intervention_parser.add_argument(
+        'action',
+        choices=['pause_strategy', 'resume_strategy', 'emergency_stop', 'force_rebalance', 'adjust_allocation'],
+        help='Intervention action to perform'
+    )
+    intervention_parser.add_argument(
+        '--strategy',
+        help='Strategy name (required for pause/resume actions)'
+    )
+    intervention_parser.add_argument(
+        '--reason',
+        help='Reason for intervention (for emergency stop)'
+    )
+    intervention_parser.add_argument(
+        '--allocation',
+        help='New allocation weights as JSON string (for adjust_allocation)'
+    )
+    
+    # API server command
+    api_orch_parser = subparsers.add_parser(
+        'orchestrator-api',
+        aliases=['orch-api'],
+        help='Manage orchestrator API server',
+        description='Start or stop the orchestrator REST API server'
+    )
+    api_orch_parser.add_argument(
+        'action',
+        choices=['start', 'stop'],
+        help='API server action'
+    )
+    api_orch_parser.add_argument(
+        '--host',
+        default='127.0.0.1',
+        help='API server host (default: 127.0.0.1)'
+    )
+    api_orch_parser.add_argument(
+        '--port',
+        type=int,
+        default=8080,
+        help='API server port (default: 8080)'
+    )
+    
+    # Migration command
+    migrate_orch_parser = subparsers.add_parser(
+        'orchestrator-migrate',
+        aliases=['orch-migrate'],
+        help='Migrate existing setup to orchestrator',
+        description='Migrate existing genebot configuration to use orchestrator'
+    )
+    migrate_orch_parser.add_argument(
+        'action',
+        choices=['analyze', 'backup', 'generate', 'migrate', 'validate', 'guide'],
+        help='Migration action to perform'
+    )
+    migrate_orch_parser.add_argument(
+        '--output',
+        help='Output path for generated configuration'
+    )
+    migrate_orch_parser.add_argument(
+        '--allocation-method',
+        choices=['equal_weight', 'performance_based', 'risk_parity'],
+        default='performance_based',
+        help='Allocation method for orchestrator (default: performance_based)'
+    )
+    migrate_orch_parser.add_argument(
+        '--rebalance-frequency',
+        choices=['daily', 'weekly', 'monthly'],
+        default='daily',
+        help='Rebalancing frequency (default: daily)'
+    )
+    migrate_orch_parser.add_argument(
+        '--max-drawdown',
+        type=float,
+        default=0.10,
+        help='Maximum portfolio drawdown (default: 0.10)'
+    )
+    migrate_orch_parser.add_argument(
+        '--no-backup',
+        action='store_true',
+        help='Skip creating backup during migration'
+    )
+
+
 def _add_account_commands(subparsers) -> None:
     """Add account management commands"""
     
@@ -1056,4 +1263,176 @@ def _add_error_handling_commands(subparsers) -> None:
         action='store_true',
         default=True,
         help='Include configuration validation (default: true)'
+    )
+
+
+def _add_orchestrator_commands(subparsers) -> None:
+    """Add orchestrator management commands"""
+    
+    # Start orchestrator command
+    start_orch_parser = subparsers.add_parser(
+        'orchestrator-start',
+        aliases=['orch-start'],
+        help='Start the strategy orchestrator',
+        description='Start the unified strategy orchestration system'
+    )
+    start_orch_parser.add_argument(
+        '--config',
+        help='Path to orchestrator configuration file'
+    )
+    start_orch_parser.add_argument(
+        '--daemon',
+        action='store_true',
+        help='Run orchestrator in daemon mode'
+    )
+    start_orch_parser.add_argument(
+        '--strategies',
+        nargs='*',
+        help='Specific strategies to enable (default: all configured)'
+    )
+    
+    # Stop orchestrator command
+    stop_orch_parser = subparsers.add_parser(
+        'orchestrator-stop',
+        aliases=['orch-stop'],
+        help='Stop the strategy orchestrator',
+        description='Stop the running strategy orchestrator gracefully'
+    )
+    stop_orch_parser.add_argument(
+        '--timeout',
+        type=int,
+        default=30,
+        help='Timeout for graceful shutdown in seconds (default: 30)'
+    )
+    
+    # Orchestrator status command
+    status_orch_parser = subparsers.add_parser(
+        'orchestrator-status',
+        aliases=['orch-status'],
+        help='Get orchestrator status and metrics',
+        description='Display current status and performance metrics of the orchestrator'
+    )
+    status_orch_parser.add_argument(
+        '--verbose',
+        action='store_true',
+        help='Show detailed status information'
+    )
+    status_orch_parser.add_argument(
+        '--format',
+        choices=['table', 'json'],
+        default='table',
+        help='Output format (default: table)'
+    )
+    
+    # Orchestrator configuration command
+    config_orch_parser = subparsers.add_parser(
+        'orchestrator-config',
+        aliases=['orch-config'],
+        help='Manage orchestrator configuration',
+        description='View and manage orchestrator configuration settings'
+    )
+    config_orch_parser.add_argument(
+        'action',
+        choices=['show', 'update', 'validate', 'reload'],
+        help='Configuration action to perform'
+    )
+    config_orch_parser.add_argument(
+        '--config',
+        help='Path to configuration file'
+    )
+    config_orch_parser.add_argument(
+        '--allocation-method',
+        choices=['equal_weight', 'performance_based', 'risk_parity', 'custom'],
+        help='Update allocation method'
+    )
+    config_orch_parser.add_argument(
+        '--rebalance-frequency',
+        choices=['daily', 'weekly', 'monthly'],
+        help='Update rebalancing frequency'
+    )
+    config_orch_parser.add_argument(
+        '--max-drawdown',
+        type=float,
+        help='Update maximum portfolio drawdown limit'
+    )
+    
+    # Orchestrator monitoring command
+    monitor_orch_parser = subparsers.add_parser(
+        'orchestrator-monitor',
+        aliases=['orch-monitor'],
+        help='Monitor orchestrator performance and metrics',
+        description='Real-time monitoring of orchestrator performance and strategy metrics'
+    )
+    monitor_orch_parser.add_argument(
+        '--hours',
+        type=int,
+        default=24,
+        help='Time range for monitoring data in hours (default: 24)'
+    )
+    monitor_orch_parser.add_argument(
+        '--format',
+        choices=['table', 'json'],
+        default='table',
+        help='Output format (default: table)'
+    )
+    monitor_orch_parser.add_argument(
+        '--refresh',
+        type=int,
+        help='Auto-refresh interval in seconds (for continuous monitoring)'
+    )
+    
+    # Manual intervention command
+    intervention_parser = subparsers.add_parser(
+        'orchestrator-intervention',
+        aliases=['orch-intervention'],
+        help='Manual intervention commands for orchestrator',
+        description='Execute manual interventions on the running orchestrator'
+    )
+    intervention_parser.add_argument(
+        'action',
+        choices=['pause_strategy', 'resume_strategy', 'emergency_stop', 'force_rebalance', 'adjust_allocation'],
+        help='Intervention action to perform'
+    )
+    intervention_parser.add_argument(
+        '--strategy',
+        help='Strategy name (required for strategy-specific actions)'
+    )
+    intervention_parser.add_argument(
+        '--weight',
+        type=float,
+        help='New allocation weight (for adjust_allocation action)'
+    )
+    intervention_parser.add_argument(
+        '--reason',
+        help='Reason for intervention (for emergency_stop action)'
+    )
+    intervention_parser.add_argument(
+        '--confirm',
+        action='store_true',
+        help='Skip confirmation prompts'
+    )
+    
+    # API server command
+    api_parser = subparsers.add_parser(
+        'orchestrator-api',
+        aliases=['orch-api'],
+        help='Start/stop orchestrator API server',
+        description='Manage the orchestrator REST API server'
+    )
+    api_parser.add_argument(
+        'action',
+        choices=['start', 'stop'],
+        default='start',
+        help='API server action (default: start)'
+    )
+    api_parser.add_argument(
+        '--host',
+        default='127.0.0.1',
+        help='API server host (default: 127.0.0.1)'
+    )
+    api_parser.add_argument(
+        '--port',
+        type=int,
+        default=8080,
+        help='API server port (default: 8080)'
     )
\ No newline at end of file
