@@ -19,66 +19,102 @@ from sqlalchemy import desc, and_, or_, func
 from .integration_manager import IntegrationManager
 # Import database components with fallbacks
 try:
+    # Try importing from src first (development)
     from src.database.connection import DatabaseManager
+    DATABASE_AVAILABLE = True
 except ImportError:
-    class DatabaseManager:
-        def __init__(self, *args, **kwargs):
-            pass
-        
-        def get_connection(self):
-            return None
+    try:
+        # Try importing from genebot package (installed)
+        from genebot.database.connection import DatabaseManager
+        DATABASE_AVAILABLE = True
+    except ImportError as e:
+        DATABASE_AVAILABLE = False
+        class DatabaseManager:
+            def __init__(self, *args, **kwargs):
+                pass
+            
+            def get_connection(self):
+                return None
+            
+            def create_tables(self):
+                pass
+            
+            def get_session(self):
+                return None
 
 try:
+    # Try importing from src first (development)
     from src.models.database_models import (
         TradeModel, OrderModel, PositionModel, StrategyPerformanceModel,
         MarketDataModel, TradingSignalModel, RiskEventModel
     )
 except ImportError:
-    # Create minimal model stubs
-    class TradeModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-    
-    class OrderModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-    
-    class PositionModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-    
-    class StrategyPerformanceModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-    
-    class MarketDataModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-    
-    class TradingSignalModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
-    
-    class RiskEventModel:
-        def __init__(self, **kwargs):
-            for k, v in kwargs.items():
-                setattr(self, k, v)
+    try:
+        # Try importing from genebot package (installed)
+        from genebot.models.database_models import (
+            TradeModel, OrderModel, PositionModel, StrategyPerformanceModel,
+            MarketDataModel, TradingSignalModel, RiskEventModel
+        )
+    except ImportError:
+        # Create minimal model stubs
+        class TradeModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
+        
+        class OrderModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
+        
+        class PositionModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
+        
+        class StrategyPerformanceModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
+        
+        class MarketDataModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
+        
+        class TradingSignalModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
+        
+        class RiskEventModel:
+            def __init__(self, **kwargs):
+                for k, v in kwargs.items():
+                    setattr(self, k, v)
 
 try:
+    # Try importing from src first (development)
     from src.monitoring.trade_logger import TradeLogger
+    TRADE_LOGGER_AVAILABLE = True
 except ImportError:
-    class TradeLogger:
-        def __init__(self, *args, **kwargs):
-            pass
-        
-        def log_trade(self, *args, **kwargs):
-            pass
+    try:
+        # Try importing from genebot package (installed)
+        from genebot.monitoring.trade_logger import TradeLogger
+        TRADE_LOGGER_AVAILABLE = True
+    except ImportError as e:
+        TRADE_LOGGER_AVAILABLE = False
+        class TradeLogger:
+            def __init__(self, *args, **kwargs):
+                pass
+            
+            def log_trade(self, *args, **kwargs):
+                pass
+            
+            def get_trade_history(self, *args, **kwargs):
+                return []
+            
+            def get_active_positions(self, *args, **kwargs):
+                return []
 from genebot.logging.factory import get_logger
 from genebot.logging.context import LogContext
 
@@ -134,6 +170,7 @@ class TradingSummary:
     sharpe_ratio: Optional[float]
     avg_win: Decimal
     avg_loss: Decimal
+    profit_factor: float = 0.0
 
 
 class RealDataManager:
@@ -154,21 +191,30 @@ class RealDataManager:
         self.logger = get_logger("trading_bot.cli.data", context)
         
         # Initialize database manager with error handling
-        try:
-            self.db_manager = DatabaseManager(database_url)
-            # Ensure database tables exist
-            self.db_manager.create_tables()
-            self.db_available = True
-        except Exception as e:
-            self.logger.warning(f"Database initialization failed: {e}")
+        if DATABASE_AVAILABLE:
+            try:
+                self.db_manager = DatabaseManager(database_url)
+                # Ensure database tables exist
+                self.db_manager.create_tables()
+                self.db_available = True
+            except Exception as e:
+                self.logger.warning(f"Database initialization failed: {e}")
+                self.db_manager = None
+                self.db_available = False
+        else:
+            self.logger.warning("Database components not available")
             self.db_manager = None
             self.db_available = False
         
         # Initialize trade logger
-        try:
-            self.trade_logger = TradeLogger(storage_path=str(self.logs_path / "trades"))
-        except Exception as e:
-            self.logger.warning(f"Trade logger initialization failed: {e}")
+        if TRADE_LOGGER_AVAILABLE:
+            try:
+                self.trade_logger = TradeLogger(storage_path=str(self.logs_path / "trades"))
+            except Exception as e:
+                self.logger.warning(f"Trade logger initialization failed: {e}")
+                self.trade_logger = None
+        else:
+            self.logger.warning("Trade logger not available")
             self.trade_logger = None
     
     def get_recent_trades(self, limit: int = 20, account_filter: Optional[str] = None, 
@@ -365,6 +411,18 @@ class RealDataManager:
             Bot status information
         """
         try:
+            # Check if database is available
+            if not self.db_available or not self.db_manager:
+                self.logger.warning("Database not available, returning default bot status")
+                return BotStatusInfo(
+                    active_positions=0,
+                    total_pnl_today=Decimal('0'),
+                    trades_today=0,
+                    active_strategies=[],
+                    last_activity=None,
+                    error_count=0
+                )
+            
             with self.db_manager.get_session() as session:
                 # Get today's date range
                 today = datetime.utcnow().date()
@@ -439,6 +497,22 @@ class RealDataManager:
             Trading summary statistics
         """
         try:
+            # Check if database is available
+            if not self.db_available or not self.db_manager:
+                self.logger.warning("Database not available, returning default trading summary")
+                return TradingSummary(
+                    total_trades=0,
+                    winning_trades=0,
+                    losing_trades=0,
+                    win_rate=0.0,
+                    total_pnl=Decimal('0'),
+                    max_drawdown=Decimal('0'),
+                    sharpe_ratio=None,
+                    avg_win=Decimal('0'),
+                    avg_loss=Decimal('0'),
+                    profit_factor=0.0
+                )
+            
             with self.db_manager.get_session() as session:
                 # Get date range
                 end_date = datetime.utcnow()
@@ -462,7 +536,8 @@ class RealDataManager:
                         max_drawdown=Decimal('0'),
                         sharpe_ratio=None,
                         avg_win=Decimal('0'),
-                        avg_loss=Decimal('0')
+                        avg_loss=Decimal('0'),
+                        profit_factor=0.0
                     )
                 
                 # Calculate basic statistics
@@ -480,6 +555,13 @@ class RealDataManager:
                 max_drawdown = performance_stats['max_drawdown']
                 sharpe_ratio = performance_stats['sharpe_ratio']
                 
+                # Calculate profit factor
+                profit_factor = 0.0
+                if avg_loss != 0:
+                    profit_factor = float(avg_win / abs(avg_loss))
+                elif avg_win > 0:
+                    profit_factor = float('inf')
+                
                 return TradingSummary(
                     total_trades=total_trades,
                     winning_trades=winning_trades,
@@ -489,7 +571,8 @@ class RealDataManager:
                     max_drawdown=max_drawdown,
                     sharpe_ratio=sharpe_ratio,
                     avg_win=avg_win,
-                    avg_loss=avg_loss
+                    avg_loss=avg_loss,
+                    profit_factor=profit_factor
                 )
                 
         except Exception as e:
@@ -503,7 +586,8 @@ class RealDataManager:
                 max_drawdown=Decimal('0'),
                 sharpe_ratio=None,
                 avg_win=Decimal('0'),
-                avg_loss=Decimal('0')
+                avg_loss=Decimal('0'),
+                profit_factor=0.0
             )
     
     def get_recent_activity(self, limit: int = 10) -> List[str]:
@@ -633,6 +717,11 @@ class RealDataManager:
     def _calculate_daily_pnl(self, days: int) -> List[float]:
         """Calculate daily PnL for the specified period"""
         try:
+            # Check if database is available
+            if not self.db_available or not self.db_manager:
+                self.logger.warning("Database not available, returning empty daily PnL")
+                return [0.0] * days
+            
             with self.db_manager.get_session() as session:
                 daily_pnl = []
                 
@@ -667,6 +756,11 @@ class RealDataManager:
     def _get_strategy_performance(self) -> Dict[str, Dict[str, Any]]:
         """Get performance data for each strategy"""
         try:
+            # Check if database is available
+            if not self.db_available or not self.db_manager:
+                self.logger.warning("Database not available, returning empty strategy performance")
+                return {}
+            
             with self.db_manager.get_session() as session:
                 strategies = session.query(StrategyPerformanceModel).all()
                 
@@ -701,6 +795,11 @@ class RealDataManager:
             Tuple of (closed_orders, failed_orders)
         """
         try:
+            # Check if database is available
+            if not self.db_available or not self.db_manager:
+                self.logger.warning("Database not available, cannot close orders")
+                return (0, 0)
+            
             with self.db_manager.get_session() as session:
                 # Get open orders
                 query = session.query(OrderModel).filter(
