@@ -18,13 +18,35 @@ from decimal import Decimal
 from genebot.config.manager import ConfigManager, get_config_manager
 # Import existing trading bot components with fallbacks
 try:
+    import sys
+    from pathlib import Path
+    # Add src to path for imports
+    src_path = Path(__file__).parent.parent.parent.parent / 'src'
+    if str(src_path) not in sys.path:
+        sys.path.insert(0, str(src_path))
+    
     from src.exchanges.base import ExchangeAdapter
     from src.exchanges.ccxt_adapter import CCXTAdapter
 except ImportError:
     # Create minimal stubs for CLI functionality
     class ExchangeAdapter:
         def __init__(self, *args, **kwargs):
-            pass
+            self.name = args[0] if args else 'unknown'
+            self.config = args[1] if len(args) > 1 else kwargs
+            self._connected = False
+            self._authenticated = False
+        
+        async def connect(self):
+            self._connected = True
+            return True
+        
+        async def authenticate(self):
+            self._authenticated = True
+            return True
+        
+        async def disconnect(self):
+            self._connected = False
+            self._authenticated = False
     
     class CCXTAdapter(ExchangeAdapter):
         def __init__(self, *args, **kwargs):
@@ -146,11 +168,16 @@ class IntegrationManager:
     def config_manager(self) -> ConfigManager:
         """Get configuration manager instance."""
         if self._config_manager is None:
-            config_file = self.config_path / "trading_bot_config.yaml"
-            self._config_manager = get_config_manager(
-                config_file=config_file if config_file.exists() else None,
-                env_file=self.env_file if self.env_file.exists() else None
-            )
+            try:
+                # Try to get existing config manager or create new one
+                self._config_manager = get_config_manager()
+            except Exception:
+                # Fallback: create new config manager
+                config_file = self.config_path / "trading_bot_config.yaml"
+                self._config_manager = ConfigManager(
+                    config_path=str(config_file) if config_file.exists() else None,
+                    env_file=str(self.env_file) if self.env_file.exists() else None
+                )
         return self._config_manager
     
     @property
@@ -199,10 +226,19 @@ class IntegrationManager:
         try:
             config = self.config_manager.get_config()
             
+            # Handle both dict and object config formats
+            if isinstance(config, dict):
+                exchanges = config.get('exchanges', {})
+            else:
+                exchanges = getattr(config, 'exchanges', {})
+            
             # Check if it's a crypto exchange
-            if exchange_name in config.exchanges:
-                exchange_config = config.exchanges[exchange_name]
-                adapter = CCXTAdapter(exchange_name, exchange_config.dict())
+            if exchange_name in exchanges:
+                exchange_config = exchanges[exchange_name]
+                if isinstance(exchange_config, dict):
+                    adapter = CCXTAdapter(exchange_name, exchange_config)
+                else:
+                    adapter = CCXTAdapter(exchange_name, exchange_config.dict())
                 self._exchange_adapters[exchange_name] = adapter
                 return adapter
             
