@@ -344,7 +344,14 @@ class ProcessManager:
                            strategies: Optional[List[str]] = None,
                            accounts: Optional[List[str]] = None) -> List[str]:
         """Build command line for starting the bot"""
-        cmd = [sys.executable, "main.py"]
+        # Use the installed genebot package's trading bot runner instead of main.py
+        # This ensures the bot runs from the packaged build, not from workspace files
+        cmd = [sys.executable, "-m", "genebot.core.runner"]
+        
+        # Set workspace path as environment variable so the runner knows where to find config
+        if not hasattr(self, '_env_vars'):
+            self._env_vars = {}
+        self._env_vars['GENEBOT_WORKSPACE'] = str(self.workspace_path)
         
         if config_file:
             cmd.extend(["--config", config_file])
@@ -704,6 +711,10 @@ class ProcessManager:
             env['PYTHONPATH'] = str(self.workspace_path)
             env['GENEBOT_INSTANCE'] = instance_name
             
+            # Add any environment variables set by _build_start_command
+            if hasattr(self, '_env_vars'):
+                env.update(self._env_vars)
+            
             self.logger.info(f"Starting instance '{instance_name}' with command: {' '.join(cmd)}")
             
             # Start process
