@@ -242,16 +242,51 @@ class CLILogger(ContextualLogger):
     def command_start(self, command: str, command_args: Dict = None, **kwargs):
         """Log command execution start."""
         args_str = f" with args: {command_args}" if command_args else ""
-        self.info(f"Executing command: {command}{args_str}", extra={'cli_event': 'command_start', 'command': command, 'command_args': command_args, **kwargs})
+        
+        # Extract custom parameters and put them in extra
+        custom_params = ['session_id', 'execution_time_s', 'context']
+        extra = kwargs.get('extra', {})
+        extra.update({'command': command, 'command_args': command_args})
+        
+        # Move custom parameters to extra and remove from kwargs
+        for param in custom_params:
+            if param in kwargs:
+                extra[param] = kwargs.pop(param)
+        
+        kwargs['extra'] = extra
+        self.info(f"Executing command: {command}{args_str}", **kwargs)
     
     def command_success(self, command: str, result: str = None, **kwargs):
         """Log successful command completion."""
         result_str = f" - {result}" if result else ""
-        self.info(f"Command completed successfully: {command}{result_str}", extra={'cli_event': 'command_success', 'command': command, 'result': result, **kwargs})
+        
+        # Extract custom parameters and put them in extra
+        custom_params = ['session_id', 'execution_time_s', 'context']
+        extra = kwargs.get('extra', {})
+        extra.update({'command': command, 'result': result})
+        
+        # Move custom parameters to extra and remove from kwargs
+        for param in custom_params:
+            if param in kwargs:
+                extra[param] = kwargs.pop(param)
+        
+        kwargs['extra'] = extra
+        self.info(f"Command completed successfully: {command}{result_str}", **kwargs)
     
     def command_error(self, command: str, error: str, **kwargs):
         """Log command execution error."""
-        self.error(f"Command failed: {command} - {error}", extra={'cli_event': 'command_error', 'command': command, 'error': error, **kwargs})
+        # Extract custom parameters and put them in extra
+        custom_params = ['session_id', 'execution_time_s', 'context']
+        extra = kwargs.get('extra', {})
+        extra.update({'command': command, 'error': error})
+        
+        # Move custom parameters to extra and remove from kwargs
+        for param in custom_params:
+            if param in kwargs:
+                extra[param] = kwargs.pop(param)
+        
+        kwargs['extra'] = extra
+        self.error(f"Command failed: {command} - {error}", **kwargs)
     
     def progress(self, message: str, current: int = None, total: int = None, **kwargs):
         """Log progress information."""
@@ -261,12 +296,34 @@ class CLILogger(ContextualLogger):
         else:
             progress_str = ""
         
-        self.info(f"Progress: {message}{progress_str}", extra={'cli_event': 'progress', 'progress_message': message, 'current': current, 'total': total, **kwargs})
+        # Extract custom parameters and put them in extra
+        custom_params = ['session_id', 'execution_time_s', 'context']
+        extra = kwargs.get('extra', {})
+        extra.update({'progress_message': message, 'current': current, 'total': total})
+        
+        # Move custom parameters to extra and remove from kwargs
+        for param in custom_params:
+            if param in kwargs:
+                extra[param] = kwargs.pop(param)
+        
+        kwargs['extra'] = extra
+        self.info(f"Progress: {message}{progress_str}", **kwargs)
     
     def user_info(self, message: str, **kwargs):
         """Log user-facing information."""
         if self.verbose or kwargs.get('force', False):
-            self.info(f"Info: {message}", extra={'cli_event': 'user_info', 'user_message': message, **kwargs})
+            # Extract custom parameters and put them in extra
+            custom_params = ['session_id', 'execution_time_s', 'context']
+            extra = kwargs.get('extra', {})
+            extra.update({'user_message': message})
+            
+            # Move custom parameters to extra and remove from kwargs
+            for param in custom_params:
+                if param in kwargs:
+                    extra[param] = kwargs.pop(param)
+            
+            kwargs['extra'] = extra
+            self.info(f"Info: {message}", **kwargs)
 
 
 class LoggerFactory:
